@@ -3,6 +3,7 @@ import sys
 
 import boto3
 import click
+import uuid
 from bentoml.exceptions import BentoMLException
 from bentoml.utils.lazy_loader import LazyLoader
 from botocore.client import Config
@@ -116,9 +117,7 @@ def pack_from_s3(module, clz, name, bucket, path, labels=None, opts=None):
 
 @click.command()
 @click.option('--bento', help="bento name in 'name:version' format")
-@click.option('--path', help="path to saved artifacts")
-@click.option('--registry', help="private registry in 'host:port' format")
-def get_kaniko_manifest(bento, path, registry):
+def get_pod_name(bento):
     if ':' in bento:
         name, version = bento.split(':')
     else:
@@ -126,9 +125,30 @@ def get_kaniko_manifest(bento, path, registry):
         version = 'latest'
 
     pod_name = camel_to_kebab(name)
-    manifest = gen_kaniko_manifest(name, pod_name, version, path, registry)
-    click.echo(manifest)
-    return manifest
+    click.echo(pod_name)
+    return pod_name
+
+
+@click.command()
+@click.option('--bento', help="bento name in 'name:version' format")
+@click.option('--path', help="path to saved artifacts")
+@click.option('--registry', help="private registry in 'host:port' format")
+@click.option('--uid', help="unique ID")
+def get_kaniko_manifest(bento, path, registry, uid=None, silent=False):
+    if ':' in bento:
+        name, version = bento.split(':')
+    else:
+        name = bento
+        version = 'latest'
+
+    if uid is None:
+        uid = str(uuid.uuid4())[:5]
+
+    image_name = camel_to_kebab(name)
+    pod_name = '{}-{}'.format(image_name, uid)
+    manifest = gen_kaniko_manifest(name, pod_name, image_name, version, path, registry)
+    if not silent: click.echo(manifest)
+    return manifest, pod_name
 
 
 @click.command()
@@ -167,7 +187,7 @@ def get_route_manifest(bento, currev, newrev, percent):
 
 @click.command()
 @click.option('--bento', help="bento name in 'name:version' format")
-def get_saved_path(bento):
+def get_saved_path(bento, silent=False):
     # Get saved path
     yatai_client = get_default_yatai_client()
     result = None
@@ -181,7 +201,7 @@ def get_saved_path(bento):
         return None
 
     saved_path = result.uri.uri
-    click.echo(saved_path)
+    if not silent: click.echo(saved_path)
     return saved_path
 
 
@@ -208,18 +228,22 @@ def first_bento_with_label(labels):
 @click.option('--registry', help="private registry in 'host:port' format")
 @click.pass_context
 def containerize(ctx, bento, registry):
-    path = ctx.invoke(get_saved_path, bento=bento)
-    manifest = ctx.invoke(get_kaniko_manifest, bento=bento, path=path, registry=registry)
+    path = ctx.invoke(get_saved_path, bento=bento, silent=True)
+    manifest, pod_name = ctx.invoke(get_kaniko_manifest, bento=bento, path=path, registry=registry, silent=True)
     from_yaml(manifest)
+    click.echo(pod_name)
+    return pod_name
 
 
 @click.command()
 @click.option('--bento', help="bento name in 'name:version' format")
+@click.option('--pod', help="pod name")
 @click.option('--registry', help="private registry in 'host:port' format")
 @click.pass_context
-def delete_containerize_job(ctx, bento, registry):
+def delete_containerize_job(ctx, bento, pod, registry):
     path = ctx.invoke(get_saved_path, bento=bento)
-    manifest = ctx.invoke(get_kaniko_manifest, bento=bento, path=path, registry=registry)
+    uid = pod.split('-')[-1]
+    manifest, pod_name = ctx.invoke(get_kaniko_manifest, bento=bento, path=path, registry=registry, uid=uid)
     delete_from_yaml(manifest)
 
 
